@@ -1,6 +1,6 @@
-#Global variables
+﻿#Global variables
 configfolder="/home/user/.SleepAnalyser/" #users home dir with ending /
-homedir="/home/user/MyDocs"
+homedir="/home/user/"
 defaultlogfolder="/home/user/MyDocs/SleepAnalyser/" #users log dir with ending /
 ConfigFile="SleepAnalyser.conf"
 #development PC:
@@ -14,8 +14,8 @@ sample_index=0
 sample_smoothing=10 #value_smoothing at 1. level
 value_smoothing=10 #value_smoothing at 2. level
 derivation=5 #shift in derivation
-Ysize=120 #default value Y scale in px
-Yscale=3 #default value Y stretching
+Ysize=121 #default value Y scale in px
+Yscale=1 #default value Y stretching
 arrXscale=[1, 4, 6] #scaling steps X accis
 arrXscaleLen=3
 Xscale=1 #default value X scale in arraXscale index
