@@ -149,6 +149,7 @@ def StartMeasurement():
     data.sample_index=0
     data.values_total=0
     data.arrDataIndex=0
+    data.Note=""
     
     for i in range(0,  len(data.arrData)): #clear data of old records
         for j in range(0,  5): data.arrData[j][i]=0
@@ -190,7 +191,7 @@ def StartMeasurement():
 def StopMeasurement():
     global app
     data.run=0
-    print "Stop timers..."
+#    print "Stop timers..."
     app.timer_GetData.stop()
     data.run=0
     StopLogfile()       
@@ -358,7 +359,6 @@ class frmStartWindow(QMainWindow):
         ViewWindow.ShowLogFile()
         
         if(data.logfilename!=""):
-            print "ViewWindow.show()"
             ViewWindow.show()
         else:
             "No valid file selected"
@@ -381,6 +381,7 @@ class frmStartWindow(QMainWindow):
             data.version = file.readline()
             data.version=data.version[:-1]
             data.build = file.readline()
+            print "Application version:",  data.version,  "Build:",  data.build
         except:
             print "Version file not found"
         self.ui.lblVersion.setText("Version: "+data.version+"-"+data.build)
@@ -462,6 +463,7 @@ class frmRecordWindow(QMainWindow):
         self.ui.lblStarttime.setText(t)
         self.ui.lblSamples_Taken.setText("0")
         self.ui.lblElapsedTime.setText("00:00:00")
+        self.ui.lblNote.setText("")
 #        self.ui.lblYscale.setText(str(data.Yscale))
 #        self.ui.lblTrigger.setText(str(data.trigger))
         self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"SleepAnalyser.png"))
@@ -543,9 +545,16 @@ class frmRecordWindow(QMainWindow):
             data.lastlogfile=data.logfilename
 #            print "lastlogfile:",  data.lastlogfile
             config.set('main', 'lastlogfile', str(data.lastlogfile))   
+            
+            self.EditNote() #request adding a note
 
 
-
+    def EditNote(self):
+        r=QInputDialog.getText(None,  "Add Note",  "Add a note to this record:\n(leave empty for no note)",  QLineEdit.Normal,  data.Note)
+        if(r[1]==True): #OK pressed
+            data.Note=str(r[0])
+            self.ui.lblNote.setText(str(data.Note))
+            ChangeNoteInFile() #rewrite log file (only do when recording is stopped!)
 
 
 
@@ -606,26 +615,38 @@ class frmViewWindow(QMainWindow):
 
     def UpdateScreen(self):
         shortfolder=string.replace(data.logfolder, data.homedir, "~/")
-        shortfolder=string.replace(data.logfolder, "//", "/") #workaround
+        shortfolder=string.replace(shortfolder, "//", "/") #workaround
         self.ui.lblLogfile.setText(data.logfilename+" (in "+shortfolder+")")
 #        self.ui.lblStarttime.setText("Start: "+str(data.arrData[0][0]))
 #        self.ui.lblStoptime.setText("End: "+str(data.arrData[0][data.arrDataIndex-1]))
 #        self.ui.lblTrigger.setText(str(data.trigger))
 #        self.ui.lblYscale.setText(str(data.Yscale))
         
+#        print "MidnightTransitions:",  data.MidnightTransitions
         try:
             start=str(data.StartDate)+" "+str(data.arrData[0][0])
-            stop=str(data.arrData[0][data.arrDataIndex-1])
+            stop=str(data.StartDate)+" "+str(data.arrData[0][data.arrDataIndex-1]) #note: stop date will be wrong if recording went beond midnight
             t0=time.strptime(start, "%d-%m-%Y %H:%M:%S")
-            t1=time.strptime("01-01-2000 "+stop, "%d-%m-%Y %H:%M:%S")
+            t1=time.strptime(stop, "%d-%m-%Y %H:%M:%S")
+    #        t1[2]=t1[2]+data.MidnightTransitions
+    #        print t0,  t1
             tt0=time.mktime(t0)
-            tt1=time.mktime(t1)
+            tt1=time.mktime(t1)+86400*data.MidnightTransitions #correction for Midnight Transitions
+    #        print tt0,  tt1,  tt1-tt0
+            d0=strftime("%a. %d.%m.%Y  %H:%M:%S", time.gmtime(tt0))
+            d1=strftime("%a. %d.%m.%Y  %H:%M:%S", time.gmtime(tt1))
             dt=strftime("%H:%M:%S", time.gmtime(tt1-tt0))
-            day=strftime("%A", time.gmtime(tt0))
+    #        print dt
+            day0=strftime("%a.", time.gmtime(tt0))
+            day1=strftime("%a.", time.gmtime(tt1))
+    #        except:
+    #            dt=""
+    #            day=""         
+    #        self.ui.lblTimes.setText("Start: "+str(day0)+" "+str(data.arrData[0][0])+"   End: "+str(day1)+" "+str(data.arrData[0][data.arrDataIndex-1])+"   Duration: "+str(dt))
+            self.ui.lblTimes.setText(str(d0)+"  -  "+str(d1)+"  (Duration: "+str(dt)+")")
         except:
-            dt=""
-            day=""            
-        self.ui.lblTimes.setText("Start: "+str(day)+" "+str(data.arrData[0][0])+"   End: "+str(data.arrData[0][data.arrDataIndex-1])+"   Duration: "+str(dt))
+            self.ui.lblTimes.setText("")
+            
         self.ui.lblNote.setText(str(data.Note))
 
         if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
@@ -638,7 +659,7 @@ class frmViewWindow(QMainWindow):
         if(data.trigger==0): self.ui.bLowerTrigger.setEnabled(False)
         else: self.ui.bLowerTrigger.setEnabled(True)
         
-        print len(data.arrLogFiles),  (data.arrLogFiles)
+#        print len(data.arrLogFiles),  (data.arrLogFiles)
         if(len(data.arrLogFiles)<2): #disable last/next buttons if only one file in folder
             self.ui.bNext.setEnabled(False)
             self.ui.bLast.setEnabled(False)
@@ -740,11 +761,11 @@ class frmViewWindow(QMainWindow):
     def OpenRecord(self):
         tmp=self.ShowFileDialog()
         if(not os.path.exists(tmp)): #only continue if valid log file selected
-            print "OpenRecord: File does not exist"
+#            print "OpenRecord: File does not exist"
 #            ViewWindow.hide()
 #            StartWindow.show()
             return 
-        print "OpenRecord: File ok"
+#        print "OpenRecord: File ok"
         tmp2=tmp.split("/")
         l=len(tmp2)    
         data.logfilename=tmp2[l-1]
@@ -773,11 +794,11 @@ class frmViewWindow(QMainWindow):
         StartWindow.show()
 
     def EditNote(self):
-        r=QInputDialog.getText(None,  "Edit Note",  "Add a note to this record:",  QLineEdit.Normal,  data.Note)
+        r=QInputDialog.getText(None,  "Edit Note",  "Add a note to this record:\n(leave empty for no note)",  QLineEdit.Normal,  data.Note)
         if(r[1]==True): #OK pressed
             data.Note=str(r[0])
             self.ui.lblNote.setText(str(data.Note))
-            ChangeNoteInFile() #rewrite log file
+            ChangeNoteInFile() #rewrite log file (only do when recording is stopped!)
 
 
 
