@@ -28,13 +28,6 @@ def StartLogfile(interval):
     except:
         print "Failed to create logfolder!"
         
-#    print "Get IMEI number..."
-#    if(data.demo==0):
-#        x = os.popen('run-standalone.sh dbus-send --system --print-reply --type=method_call --dest=com.nokia.phone.SIM /com/nokia/phone/SIM/security Phone.Sim.Security.get_imei').read()
-#        x2=string.split(x, "\"")
-#        imei=x2[1]
-#        ID=imei[10:]
-#    else: ID="00000"    
     
     #open file, write header
     data.StartTime=time.localtime()
@@ -45,10 +38,12 @@ def StartLogfile(interval):
     print "Created logfile "+data.logfilename
     t="Time, AccX, AccY, "
     d=strftime("%d-%m-%Y", data.StartTime)
-    data.logfile.write(t+"User: "+data.user+", SW version: "+data.version+", Date: " + d + \
+    data.Header=t+"User: "+data.user+", SW version: "+data.version+", Date: " + d + \
             ", Sampling interval: " + str(interval)+" ms, sampling smoothing: " +str(data.sample_smoothing)+ \
-            ", value_smoothing: " + str(data.sample_smoothing )+"\n") #Print file header
+            ", value_smoothing: " + str(data.sample_smoothing )+"\n"
+    data.logfile.write(data.Header)
     data.logfile.write("Note: \n")
+    data.Note=""
 
 
 
@@ -87,9 +82,9 @@ def LoadFileList():
     output = os.popen("cd "+str(data.logfolder)+"; ls -C1 *.csv").read() # run ls and make the output look like a file I can read
     data.arrLogFiles=output.split("\n")
     data.arrLogFiles.pop()
-    print data.arrLogFiles
+    if(data.debug==1): print data.arrLogFiles
     if(data.logfilename>""):
-        print data.logfilename
+        if(data.debug==1): print data.logfilename
         data.arrLogFileIndex=0
         for i in range(len(data.arrLogFiles)):
             if(data.logfilename==data.arrLogFiles[i]): data.arrLogFileIndex=i
@@ -120,7 +115,7 @@ def OpenLogFile():
     ret=0
     try:
         data.Header=file.readline()
-        print "Header:",  data.Header
+        if(data.debug==1): print "Header:",  data.Header
         h=string.split(data.Header, ", ")
         x=h[4] #SW version
         SWversion=string.replace(x, "SW version:",  "")
@@ -139,19 +134,27 @@ def OpenLogFile():
             data.Note=""
             data.Header=string.replace(data.Header,  x,  "SW version: "+str(data.version))
 #            print "New header:",  data.Header
-        print "Note:",  data.Note
+        if(data.debug==1): print "Note:",  data.Note
             
             
         x=h[5] #Date
         data.StartDate=string.replace(x, "Date: ",  "")
             
-        
+        data.MidnightTransitions=0
         for line in file:
 #            print line
             d=string.split(line,  ", ")
             data.arrData[0][data.arrDataIndex]=d[0] #time
             data.arrData[1][data.arrDataIndex]=int(d[1]) #X
             data.arrData[2][data.arrDataIndex]=int(d[2]) #Y
+            
+            #check for transitions beond midnight:
+            if(data.arrDataIndex>0): 
+#                print data.arrDataIndex, data.arrData[0][data.arrDataIndex],  data.arrData[0][data.arrDataIndex-1]
+                if(data.arrData[0][data.arrDataIndex][:2]=="00" and  data.arrData[0][data.arrDataIndex-1][:2]=="23"):
+                    data.MidnightTransitions=data.MidnightTransitions+1
+#                    print data.arrDataIndex, "Midnight transition:",  data.MidnightTransitions
+            
             data.arrDataIndex=data.arrDataIndex+1            
             if(data.arrDataIndex==data.arrDataLen): 
                 print "Stopped, array is full, file is to big"
@@ -172,8 +175,7 @@ def OpenLogFile():
 ###########################################################################
 def ChangeNoteInFile():    
     file = open(data.logfolder+data.logfilename, 'w')
-    print "Open logfile",  data.logfilename
-    print "Change Note to\"",  data.Note,  "\" in file",  data.logfilename
+    print "Open logfile",  data.logfilename,  ", change Note to\"",  data.Note,  "\" in file",  data.logfilename
    
    
     file.write(data.Header)
@@ -231,14 +233,14 @@ def LoadConfig():
 
     
     #print usefull data
-    print "SW version:", data.version
+#    print "SW version:", data.version
 #    print "Sampling interval:", data.sampling, "ms"
 #    print "sample_smoothing:", data.sample_smoothing, "x"
 #    print "value_smoothing:", data.value_smoothing, "x"
 #    print "=> log interval:", data.sampling*data.value_smoothing/1000, "s"
 #    print "Derivation:", data.derivation, "(substracts value", data.derivation, "- value 0)"  
 #    print "Trigger level:", data.trigger
-    print "Yscale (for graph only):",  data.Yscale
+#    print "Yscale (for graph only):",  data.Yscale
 
     return config
 
