@@ -149,7 +149,7 @@ def showGraph(self,  QtGui):
         x=data.arrDataIndex/Xscale
         if(x>775): 
             GraphStart=(x-775)*Xscale
-            print "Graph too long, only show values",  GraphStart,  "to",  x
+            if(data.debug==1): print "Graph too long, only show values",  GraphStart,  "to",  x
         else: GraphStart=0
             
         try:
